Crate engcon_macros

Crate engcon_macros 

EngCon

EngCon (Engineering Contracts) is a set of macros and traits defining contracts often found in engineering problems, e.g. the design of a distilation column.

This crate only contains derive macros for use with the engcon crate. The macros provied by this crate are also available by enabling the derive feature in aforementioned engcon crate.

Derive Macros

Validatable
Makes a type validateable, means it implements the [engcon::Validator] trait.